@@ -1,11 +1,6 @@
 from gettext import gettext as _
 from gettext import ngettext
 
-class UnknownCategory (Exception):
-	def __init__ (self, category_name, match):
-		print "** Unknown Category '%s' requested by %s" % (category_name, match.__class__)
-
-
 _generic_nest = lambda n: ngettext("%s more result", "%s more results", n)
 
 CATEGORIES = {
@@ -32,6 +27,16 @@ CATEGORIES = {
 		"nest": lambda n: ngettext("%s more document", "%s more documents", n), 
 		"threshold": 5
 	},
+	"emails"	: {	
+		"name": _("Emails"),
+		"nest": lambda n: ngettext("%s more email", "%s more emails", n), 
+		"threshold": 5
+	},
+	"conversations"	: {	
+		"name": _("Conversations"),
+		"nest": lambda n: ngettext("%s more conversation", "%s more conversations", n), 
+		"threshold": 5
+	},
 	"files"	: {	
 		"name": _("Files"),
 		"nest": lambda n: ngettext("%s more file", "%s more files", n), 
