@@ -1,9 +1,9 @@
 import os, sys, pydoc
-from os.path import abspath, expanduser, join
+from os.path import abspath, expanduser, join, basename
 import traceback
 import gtk, gobject
 
-import deskbar, deskbar.Handler
+import deskbar, deskbar.Handler, deskbar.Categories
 from deskbar.Watcher import DirWatcher
 from deskbar.ModuleContext import ModuleContext
 
@@ -68,7 +68,12 @@ class ModuleLoader (gobject.GObject):
 		res = []
 		for d in self.dirs:
 			try:
-				res += [join(d, m) for m in os.listdir (d) if self.is_module(m)]
+				if not os.path.exists(d):
+					continue
+
+				for i in [join(d, m) for m in os.listdir (d) if self.is_module(m)]:
+					if basename(i) not in [basename(j) for j in res]:
+						res.append(i)
 			except OSError, err:
 				print >> sys.stderr, "Error reading directory %s, skipping." % d
 				traceback.print_exc()
@@ -162,6 +167,11 @@ class ModuleLoader (gobject.GObject):
 		print "Initializing %s" % context.infos["name"]
 		try:
 			context.module.initialize ()
+			
+			# Add necessary categories
+			if "categories" in context.infos:
+				for catname, catinfo in context.infos["categories"].items():
+					deskbar.Categories.CATEGORIES[catname] = catinfo
 		except Exception, msg:
 			print "Error while initializing %s: %s" % (context.infos["name"],msg)
 			traceback.print_exc()
@@ -182,6 +192,11 @@ class ModuleLoader (gobject.GObject):
 		print "Stopping %s" % context.infos["name"]
 		context.module.stop ()
 		
+		# Remove the category installed by this module
+		if "category" in context.infos:
+			catname, catinfo = context.infos["category"]
+			del deskbar.Categories.CATEGORIES[catname]
+				
 		context.enabled = False
 		self.emit("module-stopped", context)
 			
